@@ -3,16 +3,28 @@ from copy import deepcopy
 import sqlglot.expressions as exp
 
 
+class chainable:
+    def __init__(self, func):
+        self.func = func
+
+    def __set_name__(self, owner, name):
+        def wrapper(rewriter, *args, **kwargs):
+            expression = self.func(rewriter, *args, **kwargs)
+            return Rewriter(expression, rewriter.copy)
+
+        setattr(owner, name, wrapper)
+
+
 class Rewriter:
     def __init__(self, expression, copy=True):
         self.copy = copy
         self.expression = deepcopy(expression) if copy else expression
 
+    @chainable
     def ctas(self, table, db=None, file_format=None):
         create = self.expression.find(exp.Create)
 
         if create:
-            create = create[0]
             create.args['db'] = db
             create.args['this'] = table
             create.args['file_format'] = exp.FileFormat(this=file_format)
@@ -24,4 +36,4 @@ class Rewriter:
                 file_format = exp.FileFormat(this=file_format),
             )
 
-        return Rewriter(create, self.copy)
+        return create
